@@ -1,5 +1,5 @@
+from .channel import Channel as Channel
 from .client import ClientWire as ClientWire
-from .client import Provider as Provider
 from .client import connect as connect
 from .server import Room as Room
 from .server import RoomManager as RoomManager
